# Generated by Django 4.2.20 on 2025-03-13 17:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("volunteers", "0005_add_required_permission"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="tasktemplate",
            options={
                "permissions": (
                    ("accept_video_tasks", "Can accept video tasks"),
                    ("accept_talkmeister_tasks", "Can accept talkmeister tasks"),
                    ("accept_fd_tasks", "Can accept front desk tasks"),
                )
            },
        ),
    ]



from django.core.mail import EmailMultiAlternatives
from django.core.management.base import BaseCommand
from django.contrib.sites.models import Site
from django.template import Context, Template

from register.models import Attendee
from register.views import STEPS


SUBJECT = '{{ WAFER_CONFERENCE_NAME }}: Incomplete Registration'
TXT = '''Hi {{ name }},

We see you started a registration for {{ WAFER_CONFERENCE_NAME }}, but never
completed it.  This means you are not currently registered to attend.
Registration is only complete once you have gone through all the steps and
received a confirmation mail.  If you still plan to attend DebConf, please go
visit the registration page and complete all the steps.

{% if billable %}This will generate an invoice.{% endif %}

Best regards,

The {{ WAFER_CONFERENCE_NAME }} team
'''


class Command(BaseCommand):
    help = "Badger users who started but didn't finish registration"

    def add_arguments(self, parser):
        parser.add_argument('--yes', action='store_true',
                            help='Actually do something')
        parser.add_argument('--site', type=int, default=1,
                            help='Django site ID, default: 1')

    def badger(self, user, dry_run, site):
        context = Context({
            'name': user.userprofile.display_name(),
            'billable': user.attendee.billable(),
            'WAFER_CONFERENCE_NAME': site.name,
        })

        txt = Template(TXT).render(context)
        subject = Template(SUBJECT).render(context)
        to = user.email
        if dry_run:
            print('I would badger:', to)
            return
        email_message = EmailMultiAlternatives(subject, txt, to=[to])
        email_message.send()

    def handle(self, *args, **options):
        dry_run = not options['yes']
        if dry_run:
            print('Not actually doing anything without --yes')
        site = Site.objects.get(id=1)
        for attendee in Attendee.objects.filter(completed_register_steps__lt=len(STEPS) - 1):
            self.badger(attendee.user, dry_run, site)



# Generated by Django 4.2.20 on 2025-05-02 20:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("minidebconf", "0011_alter_registration_phone_number"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="conference_check_in",
            field=models.BooleanField(
                default=False, verbose_name="Checked in to the conference"
            ),
        ),
    ]



from django.conf import settings
from minidebconf.models import Registration

def expose_settings(request):
    registration = None
    try:
        if request.user.is_authenticated:
            registration = Registration.objects.get(user=request.user)
    except Registration.DoesNotExist:
        pass

    return {
        'MINIDEBCONF': True,
        'MINIDEBCONF_REGISTRATION': registration,
        'MINIDEBCONF_REGISTER_BURSARY_CONTRIBUTORS_ONLY': getattr(settings, "MINIDEBCONF_REGISTER_BURSARY_CONTRIBUTORS_ONLY", False),
    }



from django.conf import settings
from django.core.mail import EmailMultiAlternatives
from django.core.management.base import BaseCommand
from django.contrib.sites.models import Site
from django.template import Context, Template

from register.models import Attendee


SUBJECT = '{{ WAFER_CONFERENCE_NAME }}: Invoice Cancelled'
TXT = '''Dear {{ name }},

Sorry, we see you had an outstanding invoice that doesn't apply any more
(due to a bursary or other change).

We have cancelled it.

Apologies for hassling about paying it.

Invoice number #{{ invoice_number }}

See you soon in {{ DEBCONF_CITY }},

The {{ WAFER_CONFERENCE_NAME }} Registration Team
'''


class Command(BaseCommand):
    help = ("Cancel invoices for attendees who got bursaries")

    def add_arguments(self, parser):
        parser.add_argument('--yes', action='store_true',
                            help='Actually do something')
        parser.add_argument('--site', type=int, default=1,
                            help='Django site ID, default: 1')

    def badger(self, attendee, dry_run, site):
        user = attendee.user
        invoice = attendee.new_invoices.first()
        context = Context({
            'invoice_number': invoice.reference_number,
            'name': user.userprofile.display_name(),
            'WAFER_CONFERENCE_DOMAIN': site.domain,
            'WAFER_CONFERENCE_NAME': site.name,
            'DEBCONF_CITY': settings.DEBCONF_CITY,
        })

        txt = Template(TXT).render(context)
        subject = Template(SUBJECT).render(context)
        to = user.email
        if dry_run:
            print('I would badger:', to)
            return
        email_message = EmailMultiAlternatives(subject, txt, to=[to])
        email_message.send()
        invoice.status = 'canceled'
        invoice.save()

    def handle(self, *args, **options):
        dry_run = not options['yes']
        if dry_run:
            print('Not actually doing anything without --yes')
        site = Site.objects.get(id=1)
        for attendee in Attendee.objects.all():
            if not attendee.user.userprofile.is_registered():
                continue
            if not attendee.new_invoices.exists():
                continue
            if not attendee.billable():
                self.badger(attendee, dry_run, site)



# Generated by Django 4.2.20 on 2025-07-07 15:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("front_desk", "0003_checkin_bedding"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="checkin",
            name="key_card",
        ),
        migrations.AddField(
            model_name="checkin",
            name="transit_card",
            field=models.BooleanField(default=False),
        ),
    ]



from datetime import date

from django.forms import ModelForm, Select
from django.forms.widgets import DateInput

from crispy_forms.helper import FormHelper
from crispy_forms.layout import Submit

from register.fields import RequiredCountries

from daytrip.models import TravelInsurance


class NativeDateInput(DateInput):
    """DateInput using an HTML5 native widget"""

    input_type = "date"

    def __init__(self, attrs=None, *args, **kwargs):
        if attrs:
            for key in ("min", "max"):
                if isinstance(attrs.get(key), date):
                    attrs[key] = attrs[key].isoformat()
        super().__init__(attrs, *args, **kwargs)


class TravelInsuranceForm(ModelForm):
    class Meta:
        model = TravelInsurance
        exclude = ["attendee"]
        widgets = {
            "country": Select(
                choices=RequiredCountries(),
            ),
            "date_of_birth": NativeDateInput(
                attrs={
                    "max": date.today,
                }
            ),
        }

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.helper = FormHelper()
        self.helper.include_media = False
        self.helper.add_input(Submit('save', 'Save'))



import re
from datetime import datetime

from django.core.management.base import BaseCommand
from django.utils.dateparse import parse_datetime

import requests


class Command(BaseCommand):
    help = "Retry previously failed mailing list subscriptions"
    subscribed = {}

    def add_arguments(self, parser):
        parser.add_argument('--yes', action='store_true',
                            help='Actually do something')
        parser.add_argument('--since', type=parse_datetime, metavar='TIMESTAMP',
                            default=datetime(2000, 1, 1),
                            help='Skip log entries before TIMESTAMP')
        parser.add_argument("--timeout", type=int,
                            default=5,
                            help="Timeout waiting for lists.debian.org")
        parser.add_argument('log', type=open,
                            help='Log file to search for failed subscriptions')

    def subscribe(self, address, lists, timeout):
        if set(lists) <= self.subscribed.get(address, set()):
            return
        try:
            requests.post(
                'https://lists.debian.org/cgi-bin/subscribe.pl',
                data={
                    'user_email': address,
                    'subscribe': lists,
                },
                timeout=timeout,
            )
        except requests.Timeout:
            print(f"Failed to subscribe {address} to {lists}")
        self.subscribed.setdefault(address, set()).update(set(lists))

    def handle(self, *args, **options):
        for line in options['log']:
            if m := re.match(
                    r'(^[0-9: -]{19}),\d+\s+INFO\s+register.views.attendee '
                    r'Failed to subscribe (\S+) to \[([a-z\', -]+)\]$',
                    line.strip()):
                timestamp = m.group(1)
                if parse_datetime(timestamp) < options['since']:
                    continue

                address = m.group(2)
                lists = [list.strip("' ") for list in m.group(3).split(',')]
                if not options['yes']:
                    print(f"Would subscribe {address} to {lists}")
                else:
                    self.subscribe(address, lists, options['timeout'])



# Generated by Django 4.2.16 on 2024-12-08 15:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("minidebconf", "0009_alter_registration_diet_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="check_in",
            field=models.DateField(
                blank=True, default=None, null=True, verbose_name="Check-in date"
            ),
        ),
        migrations.AddField(
            model_name="registration",
            name="check_out",
            field=models.DateField(
                blank=True, default=None, null=True, verbose_name="Check-out date"
            ),
        ),
    ]



from django.conf import settings
from django.contrib.auth.mixins import LoginRequiredMixin
from django.core.exceptions import PermissionDenied
from django.http import HttpResponse, Http404
from django.views import View
from django.views.generic import TemplateView
from django.views.generic.edit import UpdateView, DeleteView
from django.urls import reverse
from minidebconf.forms import register_form_factory
from minidebconf.models import Registration, is_registered


from qrcode import QRCode


class RegistrationMixin:
    @property
    def user(self):
        return self.request.user

    def get_object(self):
        if is_registered(self.user):
            return Registration.objects.get(user=self.user)
        else:
            return Registration(user=self.user)



class RegisterView(LoginRequiredMixin, RegistrationMixin, UpdateView):
    template_name = 'minidebconf/register.html'

    def dispatch(self, request, *args, **kwargs):
        if not settings.WAFER_REGISTRATION_OPEN:
            raise PermissionDenied("Registration is closed")
        return super().dispatch(request, *args, **kwargs)

    def get_form_class(self):
        return register_form_factory()

    def get_success_url(self):
        return reverse('registration_finished')


class UnregisterView(LoginRequiredMixin, RegistrationMixin, DeleteView):

    def get_success_url(self):
        return reverse('wafer_user_profile', args=[self.user.username])


class RegistrationFinishedView(LoginRequiredMixin, TemplateView):
    template_name = 'minidebconf/registration_finished.html'


class RegistrationQRCodeImageView(LoginRequiredMixin, RegistrationMixin, View):
    def get(self, request, *args, **kwargs):
        registration = self.get_object()
        if not registration.id:
            raise Http404()

        url = reverse(
            "admin:minidebconf_registration_change",
            args=(registration.pk,)
        )

        qr = QRCode()
        qr.add_data(url)

        response = HttpResponse(content_type="image/png")

        image = qr.make_image()
        image.save(response)

        return response



# Generated by Django 4.2.25 on 2025-11-04 20:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("minidebconf", "0013_checkin"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="openpgp_fingerprint",
            field=models.CharField(
                blank=True, max_length=64, null=True, verbose_name="OpenPGP fingerprint"
            ),
        ),
    ]



# Generated by Django 4.2.20 on 2025-05-03 15:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("minidebconf", "0012_registration_conference_check_in"),
    ]

    operations = [
        migrations.CreateModel(
            name="CheckIn",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("minidebconf.registration",),
        ),
    ]



# Generated by Django 4.2.20 on 2025-03-13 15:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("register", "0017_security_personal_info"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="attendee",
            options={
                "permissions": [
                    ("orga_early_arrival", "Can arrive extra-early to help setup.")
                ]
            },
        ),
    ]



from datetime import timedelta
from django import forms
from django.conf import settings
from django.utils import formats
from django.utils.translation import gettext_lazy as _
from django.utils.translation import pgettext_lazy as _p

from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Fieldset, Submit, HTML

from minidebconf.models import Diet, Registration, RegistrationType, ShirtSize
from minidebconf.models import ScheduleBlock


def format_day(day):
    date = formats.date_format(day, format="SHORT_DATE_FORMAT")
    weekday = formats.date_format(day, format="l")
    return f"{date} ({weekday})"


def attendance_days():
    days = ScheduleBlock.objects.order_by("start_time")
    return [(day.pk, format_day(day.start_time)) for day in days]


def select_check_in_check_out():
    schedule = [d.start_time.date() for d in ScheduleBlock.objects.order_by("start_time")]
    one_day = timedelta(days=1)

    earliest_check_in = settings.MINIDEBCONF_REGISTER_ACCOMMODATION_EARLIEST_CHECK_IN
    earliest_check_in = earliest_check_in or (schedule[0] - one_day)

    latest_check_out = settings.MINIDEBCONF_REGISTER_ACCOMMODATION_LATEST_CHECK_OUT
    latest_check_out = latest_check_out or (schedule[-1] + one_day)

    dates = [earliest_check_in]
    date = earliest_check_in + one_day
    while date <= latest_check_out:
        dates.append(date)
        date = date + one_day

    return [(None, _("----- select date ------"))] + [(date, format_day(date)) for date in dates]


def register_form_factory():
    form_fields = ['full_name']
    if settings.MINIDEBCONF_REGISTER_PHONE is not None:
        form_fields.append('phone_number')
    if RegistrationType.objects.exists():
        form_fields.append('registration_type')
    form_fields.append('full_name')
    form_fields.append('involvement')
    form_fields.append('gender')
    form_fields.append('country')
    form_fields.append('city_state')
    if ScheduleBlock.objects.count() > 0:
        form_fields.append('days')
    if settings.MINIDEBCONF_REGISTER_ARRANGED_ACCOMMODATION:
        form_fields.append('arranged_accommodation')
        form_fields.append("check_in")
        form_fields.append("check_out")
    if settings.MINIDEBCONF_REGISTER_ARRANGED_FOOD:
        form_fields.append('arranged_food')
    if Diet.objects.exists():
        form_fields.append('diet')
    if settings.MINIDEBCONF_REGISTER_TRAVEL_REIMBURSEMENT:
        form_fields.append("travel_reimbursement")
        form_fields.append("travel_cost")
    if ShirtSize.objects.exists():
        form_fields.append('shirt_size')
    form_fields.append("notes")
    form_fields.append("openpgp_fingerprint")


    class RegisterForm(forms.ModelForm):
        full_name = forms.CharField(max_length=256, label=_('Full name'))
        class Meta:
            model = Registration
            fields = form_fields
            widgets = {
                'days': forms.CheckboxSelectMultiple(),
                'check_in': forms.Select(),
                'check_out': forms.Select(),
            }

        def __init__(self, *args, **kwargs):
            super().__init__(*args, **kwargs)
            self.fields["full_name"].initial = self.instance.full_name
            if 'days' in self.fields:
                self.fields["days"].choices = attendance_days()
            if 'phone_number' in self.fields:
                self.fields["phone_number"].required = settings.MINIDEBCONF_REGISTER_PHONE
            if settings.MINIDEBCONF_REGISTER_DEFAULT_COUNTRY:
                self.initial['country'] = settings.MINIDEBCONF_REGISTER_DEFAULT_COUNTRY
            if 'arranged_accommodation' in self.fields:
                self.fields['arranged_accommodation'].label = _('I would like to stay at the conference-arranged accommodation')
            if 'arranged_food' in self.fields:
                self.fields['arranged_food'].label = _('I would like to have the conference-arranged meals')
            if 'travel_reimbursement' in self.fields:
                self.fields["travel_reimbursement"].label = _('I would like to request reimbursement of my travel costs')
            if 'travel_cost' in self.fields:
                self.fields['travel_cost'].label = _('Estimated travel cost (upper bound, in %(currency)s)') % { 'currency': settings.DEBCONF_BURSARY_CURRENCY_SYMBOL }

            self.helper = FormHelper()
            phone_number = ('phone_number' in self.fields) and ['phone_number'] or []

            layout = [
                'full_name',
                *phone_number,
                'involvement',
                'gender',
                'country',
                'city_state',
                'days',
            ]
            if 'shirt_size' in self.fields:
                if page := settings.MINIDEBCONF_REGISTER_SHIRT_INFO_PAGE:
                    info = [HTML(_("<p><a href='%s' target='_blank'>See this page</a> for more information about shirt sizes.</p>") % page)]
                else:
                    info = []
                layout += [
                    Fieldset(
                        _('T-Shirt'),
                        *info,
                        'shirt_size',
                    )
                ]
            if 'arranged_food' in self.fields or 'arranged_accommodation' in self.fields or 'travel_reimbursement' in self.fields:
                accommodation_dates = select_check_in_check_out()
                if 'check_in' in self.fields:
                    self.fields['check_in'].widget.choices = accommodation_dates
                    self.fields['check_in'].initial = accommodation_dates[0][0]
                if 'check_out' in self.fields:
                    self.fields['check_out'].widget.choices = accommodation_dates
                    self.fields['check_out'].initial = accommodation_dates[-1][0]

                if page := settings.MINIDEBCONF_REGISTER_BURSARY_INFO_PAGE:
                    info = [HTML(_("<p><a href='%s' target='_blank'>See this page</a> for more information about bursaries.</p>") % page)]
                else:
                    info = []

                bursary_fields = [
                    'arranged_food',
                    'diet',
                    'arranged_accommodation',
                    'check_in',
                    'check_out',
                    'travel_reimbursement',
                    'travel_cost',
                ]

                layout += [
                    Fieldset(
                        _('Bursaries'),
                        *info,
                        *[f for f in bursary_fields if f in self.fields],
                        id='bursary_fields',
                    )
                ]

            layout += ['notes']
            layout += ['openpgp_fingerprint']

            if self.instance.id:
                submit = _p("conference", "Update registration")
            else:
                submit = _p("conference", "Register")
            layout += [Submit("submit", submit)]
            self.helper.layout = Layout(*layout)

        def clean(self):
            cleaned_data = super().clean()
            if cleaned_data.get("arranged_accommodation"):
                if not cleaned_data.get("check_in"):
                    self.add_error('check_in', _("You need to select a check-in date"))
                if not cleaned_data.get("check_out"):
                    self.add_error('check_out', _("You need to select a check-out date"))
            elif settings.MINIDEBCONF_REGISTER_ARRANGED_ACCOMMODATION:
                del cleaned_data["check_in"]
                del cleaned_data["check_out"]

            if cleaned_data.get("arranged_food") and "diet" in self.fields and not cleaned_data.get("diet"):
                self.add_error(
                    "diet",
                    _("If you are eating the arranged food, you need to select a diet"),
                )

        def save(self):
            super().save()
            name = self.cleaned_data['full_name'].split()
            user = self.instance.user
            user.first_name = name[0]
            user.last_name = " ".join(name[1:])
            user.save()
    return RegisterForm



# Generated by Django 4.2.20 on 2025-03-20 19:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bursary", "0005_alter_bursary_options_bursary_partial_contribution"),
    ]

    operations = [
        migrations.AddField(
            model_name="bursary",
            name="budget",
            field=models.CharField(
                choices=[
                    ("general", "Debian Contributor Bursary"),
                    ("diversity", "Debian Diversity Bursary (newcomers to DebConf)"),
                    ("both", "Debian Contributor and Diversity (considered for both)"),
                ],
                default="both",
                max_length=16,
            ),
            preserve_default=False,
        ),
        migrations.AlterModelOptions(
            name="bursaryreferee",
            options={
                "permissions": [
                    ("invited_speaker", "May have travel funded as a speaker"),
                    ("orga_travel", "May have travel funded as an event organizer"),
                ]
            },
        ),
    ]



# Generated by Django 4.2.20 on 2025-06-18 10:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("register", "0018_alter_attendee_options"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="attendee",
            options={
                "permissions": [
                    ("orga_early_arrival", "Can arrive extra-early to help setup."),
                    ("view_security_info", "Can view attendees' government identity."),
                ]
            },
        ),
    ]



from django.contrib.auth import get_user_model
from django.test import Client
from minidebconf.models import Registration
from minidebconf.forms import register_form_factory
from wafer.schedule.models import ScheduleBlock
from pytest import fixture
import pytest


User = get_user_model()


@fixture
def days(db):
    day1 = ScheduleBlock.objects.create(start_time='2020-06-01 09:00+00', end_time='2020-06-01 18:00+00')
    day2 = ScheduleBlock.objects.create(start_time='2020-06-02 09:00+00', end_time='2020-06-02 18:00+00')
    day3 = ScheduleBlock.objects.create(start_time='2020-06-03 09:00+00', end_time='2020-06-03 18:00+00')
    return [day1, day2, day3]



class TestRegistrationModel:

    def test_full_name(self, user):
        registration = Registration(user=user)
        assert registration.full_name == "Firstname Lastname"


class TestRegistrationForm:

    def test_basics(self, user, days):
        form = register_form_factory()(
            instance=Registration(user=user),
            initial={"days": days}
        )
        assert not form.errors

    def test_get_full_name_from_user(self, user, days):
        registration = Registration.objects.create(user=user, country="BR")
        registration.days.add(days[0])
        form = register_form_factory()(instance=registration)
        assert form.fields['full_name'].initial == registration.full_name

    def test_pass_full_name_on_to_user(self, user, days):
        form = register_form_factory()(
            instance=Registration(user=user),
            data={"days": days, "country": "BR", "full_name": 'Foo Bar'},
        )
        assert not form.errors
        form.save()
        user.refresh_from_db()
        assert user.first_name == "Foo"
        assert user.last_name == "Bar"

    def test_phone_number_not_present_by_default(self, user):
        form = register_form_factory()(instance=Registration(user=user))
        assert 'phone_number' not in form.fields

    def test_phone_number_not_required(self, user, settings):
        settings.MINIDEBCONF_REGISTER_PHONE = False
        form = register_form_factory()(instance=Registration(user=user))
        assert not form.fields['phone_number'].required

    def test_phone_number_required(self, user, settings):
        settings.MINIDEBCONF_REGISTER_PHONE = True
        form = register_form_factory()(instance=Registration(user=user))
        assert form.fields['phone_number'].required

    def test_phone_number_invalid(self, user, settings):
        settings.MINIDEBCONF_REGISTER_PHONE = False
        form = register_form_factory()(
            instance=Registration(user=user),
            data={"phone_number": 'letters'}
        )
        assert 'phone_number' in form.errors

    @pytest.mark.parametrize(
        "phone",
        [
            # Brazil
            '5571987654321',
            '+55 71 987654321',
            '+55 (71) 987654321',
            '+55 (71) 9876-54321',
            '557139876543',
            '71987654321',
            '71 987654321',
            '(71) 987654321',
            # India
            '9775876662',
            '0 9754845789',
            '91 9857842356',
            '919578965389',
        ]
    )
    def test_phone_number_valid(self, user, settings, phone):
        settings.MINIDEBCONF_REGISTER_PHONE = True
        form = register_form_factory()(
            instance=Registration(user=user),
            data={"phone_number": phone}
        )
        assert 'phone_number' not in form.errors


class TestRegistrationView:
    def test_register(self, user, client, days):
        response = client.post(
            '/register/',
            {
                "days": [days[1].id, days[2].id],
                "country": "BR",
                "full_name": "Foo Bar",
            }
        )
        assert response.status_code == 302
        registration = Registration.objects.last()
        assert registration.user == user
        assert days[0] not in registration.days.all()
        assert days[1] in registration.days.all()
        assert days[2] in registration.days.all()

    def test_update_registration(self, user, client, days):
        record = Registration.objects.create(user=user, country="BR")
        record.days.add(days[0])
        response = client.post(
            '/register/',
            {
                "days": [days[1].id],
                "country": "FR",
                "full_name": "Baz Qux",
            }
        )
        assert response.status_code == 302
        registration = Registration.objects.get(user=user)
        assert registration.days.get() == days[1]
        assert registration.country == "FR"

    def test_unauthenticated(self, db):
        client = Client()
        response = client.get("/register/")
        assert response.status_code == 302
        assert response["Location"].startswith("/accounts/login/")


class TestCancelRegistrationView:
    def test_cancel_registration(self, user, client):
        record = Registration.objects.create(user=user)
        response = client.post('/unregister/')
        assert response.status_code == 302
        assert Registration.objects.filter(user=user).count() == 0

    def test_cancel_registration_get(self, user, client):
        record = Registration.objects.create(user=user)
        response = client.get('/unregister/')
        assert response.status_code == 200


class TestClosedRegistration:
    def test_registration_forbidden(self, user, client, settings):
        settings.WAFER_REGISTRATION_OPEN = False
        response = client.get("/register/")
        assert response.status_code == 403


class TestRegistrationQRCode:
  def test_unauthenticated(self, client):
    response = client.get("/register/qr.png")
    assert response.status_code == 404

  def test_not_registered(self, user, client):
    response = client.get("/register/qr.png")
    assert response.status_code == 404

  def test_basics(self, user, attendee, client):
    response = client.get("/register/qr.png")
    assert response.status_code == 200
    assert response["content-type"] == "image/png"


class TestRegistrationQRCodeOnProfilePage:
  def test_oneself(self, attendee, client):
    response = client.get("/users/theuser/")

    assert response.status_code == 200
    assert b'Your registration ID:' in response.content

  def test_other(self, user, attendee, client):
    user.is_superuser = True
    user.save()

    otheruser = User.objects.create(
      username='otheruser',
      first_name='Fist',
      last_name='Last',
    )
    Registration.objects.create(
        user=otheruser,
        involvement=0,
        gender='n',
        country='CA',
        city_state='BC',
    )

    response = client.get("/users/otheruser/")

    assert response.status_code == 200
    assert b'Your registration ID:' not in response.content



# Generated by Django 4.2.14 on 2024-07-20 12:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("front_desk", "0002_checkin_meal_vouchers"),
    ]

    operations = [
        migrations.AddField(
            model_name="checkin",
            name="bedding",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="checkin",
            name="returned_bedding",
            field=models.BooleanField(default=False),
        ),
    ]
